==> mkagal1.3.tar.gz: mkagal1.3/convertshit.pl <==
#!/usr/bin/perl

$logfile = "convertshitlog.txt";

open (OUTFILE, ">$logfile");

if (-e "thumbs") {
print OUTFILE "thumbs folder found, good.\n";
} else {
print OUTFILE "thumbs folder not found, created.\n";
chomp($now = `mkdir thumbs`);
}

@jpglist = qw( jpg JPG jPG jpG Jpg JPg JpG jPg stop ); # File types to support

while ( $jpglist[$i] ne "stop" ) {      # Stop when the stop word is reached

while ( defined($filename = glob("*.$jpglist[$i]"))) { # Loop!


if (-e "thumbs/$filename") {

print OUTFILE "$filename, Found\n";

}

else

{



print "$filename,";
chomp($now = `convert $filename -size 96x96 -resize 96x96  +profile thumbs/$filename`);
print " done.";

print "$now\n";

&checkfile;
$filecount ++;
print OUTFILE "$filename, $filegood $now\n";

}

}

$i ++;                            # Add to the counter

}


sub checkfile {
if (-e "thumbs/$filename") {
$filegood = "Good";
$goodcount = $goodcount + 1;
} else {
$filegood = "ERROR";
$errorcount = $errorcount + 1;
$checkmode = "thumb";
}
}

print "Checking for special icons...\n";
if (-e "thumbs/foldericon.jpg") { print OUTFILE "foldericon.jpg, Found\n"; } else { chomp($now = `wget http://sae.macphreak.org/img/foldericon.jpg`); rename "foldericon.jpg", "thumbs/foldericon.jpg"; print OUTFILE "Got foldericon.jpg\n"; }

if (-e "thumbs/missingjpg.jpg") { print OUTFILE "missingjpg.jpg, Found\n"; } else { chomp($now = `wget http://sae.macphreak.org/img/missingjpg.jpg`); rename "missingjpg.jpg", "thumbs/missingjpg.jpg"; print OUTFILE "Got missingjpg.jpg\n"; }

if ( $goodcount > 0 ) {
print "$goodcount files added.\n";
}

if ( $errorcount > 0 ) {
print "$errorcount errors detected.\n";
print "Be sure to inspect $logfile.\n";
}

==> mkagal1.5.tar.gz: mkagal1.5/convertshit.pl <==
#!/usr/bin/perl

$imhack = ""; # for ImageMagick 5.5.7
#$imhack = "\"*\""; # for ImageMagick 5.4.4
$logfile = "convertshitlog.txt";

chomp($now = `pwd > folderinfo`);

open (OUTFILE, ">$logfile");

if (-e "thumbs") {
print OUTFILE "thumbs folder found, good.\n";
} else {
print OUTFILE "thumbs folder not found, created.\n";
chomp($now = `mkdir thumbs`);
}

if (-e "lowrez") {
print OUTFILE "lowrez folder found, good.\n";
} else {
print OUTFILE "lowrez folder not found, created.\n";
chomp($now = `mkdir lowrez`);
}


$filetype = "thumbs";
@jpglist = qw( jpg JPG jPG jpG Jpg JPg JpG jPg stop ); # File types to support

while ( $jpglist[$i] ne "stop" ) {      # Stop when the stop word is reached

while ( defined($filename = glob("*.$jpglist[$i]"))) { # Loop!


if (-e "thumbs/$filename") {

print OUTFILE "thumb $filename, Found\n";

}

else

{



print "$filename,";
chomp($now = `convert $filename -size 96x96 -resize 96x96  +profile $imhack thumbs/$filename`);
print " done-thumb.";

print "$now\n";

&checkfile;
$filecount ++;
print OUTFILE "thumb $filename, $filegood $now\n";

}

}

$i ++;                            # Add to the counter

}

$i = 0;

$filetype = "lowrez";
@jpglist = qw( jpg JPG jPG jpG Jpg JPg JpG jPg stop ); # File types to support

while ( $jpglist[$i] ne "stop" ) {      # Stop when the stop word is reached

while ( defined($filename = glob("*.$jpglist[$i]"))) { # Loop!


if (-e "lowrez/$filename") {

print OUTFILE "lowrez $filename, Found\n";

}

else

{



print "$filename,";
chomp($now = `convert $filename -size 640x480 -resize 640x480  +profile $imhack lowrez/$filename`);
print " done-lowrez.";

print "$now\n";

&checkfile;
$filecount ++;
print OUTFILE "lowrez $filename, $filegood $now\n";

}

}

$i ++;                            # Add to the counter

}


sub checkfile {
if (-e "$filetype/$filename") {
$filegood = "Good";
$goodcount = $goodcount + 1;
} else {
$filegood = "ERROR";
$errorcount = $errorcount + 1;
$checkmode = "thumb";
}
}

print "Checking for special icons...\n";
if (-e "thumbs/foldericon.jpg") { print OUTFILE "foldericon.jpg, Found\n"; } else { chomp($now = `wget http://sae.macphreak.org/img/foldericon.jpg`); rename "foldericon.jpg", "thumbs/foldericon.jpg"; print OUTFILE "Got foldericon.jpg\n"; }

if (-e "thumbs/missingjpg.jpg") { print OUTFILE "missingjpg.jpg, Found\n"; } else { chomp($now = `wget http://sae.macphreak.org/img/missingjpg.jpg`); rename "missingjpg.jpg", "thumbs/missingjpg.jpg"; print OUTFILE "Got missingjpg.jpg\n"; }

if (-e "mkagalerror.gif") { print OUTFILE "mkagalerror.gif, Found\n"; } else { chomp($now = `wget http://sae.macphreak.org/img/mkagalerror.gif`); print OUTFILE "Got mkagalerror.gif\n"; }

$goodcount = $goodcount / 2;

if ( $goodcount > 0 ) {
print "$goodcount files added.\n";
}

if ( $errorcount > 0 ) {
print "$errorcount errors detected.\n";
print "Be sure to inspect $logfile.\n";
}
